==> odoo_19.1a1.20251123.zip: odoo-19.1a1.post20251123/odoo/addons/web/static/tests/core/offline/offline_systray.test.js <==
import { WebClient } from "@web/webclient/webclient";

import { animationFrame, expect, test } from "@odoo/hoot";
import { contains, getService, mountWithCleanup, onRpc } from "@web/../tests/web_test_helpers";

test.tags("desktop");
test("offline systray item: basic rendering (desktop)", async () => {
    await mountWithCleanup(WebClient);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
    getService("offline").status.offline = true;

    await animationFrame();
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(1);
    expect(`.o_menu_systray .o_nav_entry:first`).toHaveText("Working offline");

    getService("offline").status.offline = false;
    await animationFrame();
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
});

test.tags("mobile");
test("offline systray item: basic rendering (mobile)", async () => {
    await mountWithCleanup(WebClient);
    expect(`.o_menu_systray .o_nav_entry.fa-chain-broken`).toHaveCount(0);
    getService("offline").status.offline = true;

    await animationFrame();
    expect(`.o_menu_systray .o_nav_entry.fa-chain-broken`).toHaveCount(1);
    expect(`.o_menu_systray .o_nav_entry:first`).toHaveAttribute("data-tooltip", "Working offline");

    getService("offline").status.offline = false;
    await animationFrame();
    expect(`.o_menu_systray .o_nav_entry.fa-chain-broken`).toHaveCount(0);
});

test.tags("desktop");
test("offline systray item: click to check connection (desktop)", async () => {
    onRpc("/web/webclient/version_info", async () => {
        expect.step("version_info");
        return true;
    });
    await mountWithCleanup(WebClient);
    getService("offline").status.offline = true;

    await contains(`.o_menu_systray .o_nav_entry .fa-chain-broken`).click();
    expect.verifySteps(["version_info"]);
    expect(getService("offline").status.offline).toBe(false);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
});

test.tags("mobile");
test("offline systray item: click to check connection (mobile)", async () => {
    onRpc("/web/webclient/version_info", async () => {
        expect.step("version_info");
        return true;
    });
    await mountWithCleanup(WebClient);
    getService("offline").status.offline = true;

    await contains(`.o_menu_systray .o_nav_entry.fa-chain-broken`).click();
    expect.verifySteps(["version_info"]);
    expect(getService("offline").status.offline).toBe(false);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
});

==> odoo_19.2a1.20260219.zip: odoo-19.2a1.post20260219/odoo/addons/web/static/tests/core/offline/offline_systray.test.js <==
import { WebClient } from "@web/webclient/webclient";

import { expect, test } from "@odoo/hoot";
import {
    contains,
    getService,
    mountWithCleanup,
    mockOffline,
    onRpc,
} from "@web/../tests/web_test_helpers";

test.tags("desktop");
test("offline systray item: basic rendering (desktop)", async () => {
    const setOffline = mockOffline();
    await mountWithCleanup(WebClient);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
    await setOffline(true);

    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(1);
    expect(`.o_menu_systray .o_nav_entry:first`).toHaveText("Working offline");

    await setOffline(false);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
});

test.tags("mobile");
test("offline systray item: basic rendering (mobile)", async () => {
    const setOffline = mockOffline();
    await mountWithCleanup(WebClient);
    expect(`.o_menu_systray .o_nav_entry.fa-chain-broken`).toHaveCount(0);
    await setOffline(true);

    expect(`.o_menu_systray .o_nav_entry.fa-chain-broken`).toHaveCount(1);
    expect(`.o_menu_systray .o_nav_entry:first`).toHaveAttribute("data-tooltip", "Working offline");

    await setOffline(false);
    expect(`.o_menu_systray .o_nav_entry.fa-chain-broken`).toHaveCount(0);
});

test.tags("desktop");
test("offline systray item: click to check connection (desktop)", async () => {
    const setOffline = mockOffline();
    onRpc("/web/webclient/version_info", async () => {
        expect.step("version_info");
        return true;
    });
    await mountWithCleanup(WebClient);
    await setOffline(true);

    await contains(`.o_menu_systray .o_nav_entry .fa-chain-broken`).click();
    expect.verifySteps(["version_info"]);
    expect(getService("offline").offline).toBe(false);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
});

test.tags("mobile");
test("offline systray item: click to check connection (mobile)", async () => {
    const setOffline = mockOffline();
    onRpc("/web/webclient/version_info", async () => {
        expect.step("version_info");
        return true;
    });
    await mountWithCleanup(WebClient);
    await setOffline(true);

    await contains(`.o_menu_systray .o_nav_entry.fa-chain-broken`).click();
    expect.verifySteps(["version_info"]);
    expect(getService("offline").offline).toBe(false);
    expect(`.o_menu_systray .o_nav_entry .fa-chain-broken`).toHaveCount(0);
});
